@@ -3,7 +3,7 @@
 #define _LIBGDAMM_VALUE_H
 
 
-/* $Id: value.h 1059 2007-03-30 13:40:09Z arminb $ */
+/* $Id: value.h 1083 2007-06-20 13:57:08Z murrayc $ */
 // -*- C++ -*- //
 
 /* value.h
@@ -221,7 +221,7 @@ public:
   
   GType get_g_type() const;
   
-  void set(GType val);
+  void set_g_type(GType val);
   
   //Use the copy constructor instead: _WRAP_METHOD(bool set_from_value(const Value& from), gda_value_set_from_value)
   
